.. SPDX-FileCopyrightText: Copyright © 2024 Idiap Research Institute <contact@idiap.ch>
..
.. SPDX-License-Identifier: GPL-3.0-or-later

.. _mednet.databases.segment.drionsdb:

===========
 DRIONS-DB
===========

* DataModule and support code: :py:mod:`.data.segment.drionsdb`
* Splits:

  .. list-table::
     :align: left

     * - Config. key
       - Module
     * - ``drionsdb``
       - :py:mod:`.config.segment.data.drionsdb.expert1`
     * - ``drionsdb-2nd``
       - :py:mod:`.config.segment.data.drionsdb.expert2`
